@@ -1,9 +1,20 @@
 #!/usr/bin/perl -w
 use strict;
-use vars qw($TEST_SERVER_PID);
+use vars qw($PERL $PATH $TEST_SERVER_PID);
+
+use Config;
+use Cwd;
 
 use constant DEFAULT_PORT => 70;
 
+# hack devised by Gisle Aas:
+$PERL = $Config{'perlpath'};
+$PERL = $^X if ($^O eq 'VMS' or -x $^X && $^X =~ m|^([a-z]:)?/|i);
+
+$PATH = (cwd() =~ m|/t$|)
+		? 'testserver.pl'
+		: './t/testserver.pl';
+
 $TEST_SERVER_PID = undef;
 
 
@@ -14,7 +25,7 @@ sub run_server
 {
 	my $port = shift || DEFAULT_PORT;
 
-	my $pid = open(SERVER, "| perl ./t/testserver.pl -p $port")
+	my $pid = open(SERVER, "$PERL $PATH -p $port |")
 		or die "Couldn't launch the test server: $!.\n";
 
 	return $TEST_SERVER_PID = $pid;
@@ -24,7 +35,7 @@ sub run_echo_server
 {
 	my $port = shift || DEFAULT_PORT;
 
-	my $pid = open(SERVER, "| perl ./t/testserver.pl -p $port -e")
+	my $pid = open(SERVER, "$PERL $PATH -ep $port |")
 		or die "Couldn't launch the test server: $!.\n";
 
 	return $TEST_SERVER_PID = $pid;
@@ -44,15 +55,4 @@ sub kill_server
 	return 1;
 }
 
-
-
-
-
-BEGIN
-{
-	$SIG{'__DIE__'} = sub { kill_server() };
-	$SIG{'INT'}     = sub { kill_server() };
-	$SIG{'CHLD'}    = 'IGNORE';
-}
-
 1;
